﻿using Kivii.Client.OfficeSample.Entities;
using Kivii.Office.OpenXml.Excel.Templates;
using System;
using System.Diagnostics;
using System.IO;
using System.Windows.Forms;

namespace Kivii.Client.OfficeSample
{
    public partial class FrmMain : Form
    {
        private Contract _contract = null;
        private RestfulQueryResponse<Task> _tasks = null;
        public FrmMain()
        {
            InitializeComponent();
        }
        private void FrmMain_Load(object sender, EventArgs e)
        {
            tbxTemplateFileName.Text = Path.Combine(AppDomain.CurrentDomain.BaseDirectory, "附页模板.xlsx");
            dgTasks.AutoGenerateColumns = false;
        }
        private void btnGetReport_Click(object sender, EventArgs e)
        {
            JsonServiceClient client = new JsonServiceClient(tbxServiceUrl.Text);
            var query = new ContractQuery();
            query.ReportId = tbxReportId.Text;
            var results = client.Get(query);
            if (results.Results.Count < 1)
            {
                MessageBox.Show("未查询到报告");
                return;
            }
            _contract = results.Results[0];
            //显示各个属性值
            pgResult.SelectedObject = _contract;

            var taskQuery = new TaskQuery();
            taskQuery.ContractKvid = _contract.Kvid;
            taskQuery.OrderBy = "StandardSortId,SortId";
            _tasks = client.Get(taskQuery);
            dgTasks.DataSource = _tasks.Results;
        }

        private void btnSelectTemplateFile_Click(object sender, EventArgs e)
        {
            OpenFileDialog ofd = new OpenFileDialog();
            ofd.Filter = "Excel模板文件|*.xlsx";
            if (ofd.ShowDialog() != DialogResult.OK) return;
            tbxTemplateFileName.Text = ofd.FileName;

        }

        private void btnGenerateXlsx_Click(object sender, EventArgs e)
        {
            //先获取要保存的文件名称
            SaveFileDialog sfd = new SaveFileDialog();
            sfd.Filter = "Excel文件|*.xlsx";
            if (sfd.ShowDialog() != DialogResult.OK) return;
            var saveFileName = sfd.FileName;

            Stopwatch watch = new Stopwatch();
            watch.Start();
            //创建个模板引擎
            var template = new TemplateExcel();
            template.Open(tbxTemplateFileName.Text);//打开模板文件

            template.Bind("contract", _contract);//将数据绑定到模板中，注意contract在模板中这是这个变量名了
            template.Bind("task", _tasks);
            var rtns =template.Fill();//填充模板

            template.SaveAs(saveFileName);//最后另存当前的文件
            watch.Stop();
            lblSpendTime.Text = $"共花费{watch.ElapsedMilliseconds}毫秒,共填充了{rtns.Count}个项目";
        }


    }
}
